commit 08efd16038a01e1eed81f47649223cb1be57113b
Author: Bryn M. Reeves <bmr@redhat.com>
Date:   Tue Jul 30 17:42:40 2013 +0100

    Restrict wbinfo collection to the current domain.
    
    The samba module calls the wbinfo command to collect user and
    group information. This by default will search all domains to
    which the host has access. In a large AD environment with a number
    of trusted domains this causes the winbindd process to consume
    excessive CPU and memory resources.
    
    The Samba developers have commented that fixing this would require
    a complete rewrite of the winbind protocol and wbinfo client.
    
    Since listing out the _entire_ set of visible users is unlikely
    to be of any use anyway pass the --domain='.' option to restrict
    the search to the current domain of the system.
    
    Signed-off-by: Bryn M. Reeves <bmr@redhat.com>
    
    Conflicts:
    	sos/plugins/samba.py

diff --git a/sos/plugins/samba.py b/sos/plugins/samba.py
index 1e33758..2d1413b 100644
--- a/sos/plugins/samba.py
+++ b/sos/plugins/samba.py
@@ -22,8 +22,7 @@ class samba(sos.plugintools.PluginBase):
         self.addCopySpec("/var/log/samba/*")
         self.addCopySpec("/etc/krb5.conf")
         self.addCopySpec("/etc/krb5.keytab")
-        self.collectExtOutput("/usr/bin/wbinfo -g")
-        self.collectExtOutput("/usr/bin/wbinfo -u")
+        self.collectExtOutput("/usr/bin/wbinfo --domain='.' -g")
+        self.collectExtOutput("/usr/bin/wbinfo --domain='.' -u")
         self.collectExtOutput("/usr/bin/testparm -s -v")
         return
-
